---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
<-- A clear and concise description of what the bug is. -->

**To Reproduce**
<-- Describe the steps to reproduce the behavior. -->

**Expected behavior**
<-- A clear and concise description of what you expected to happen. -->

**Environment information**

* HMC version:

* Output of `python -c "import zhmcclient; print(zhmcclient.debuginfo())"`:
